from flask import jsonify
from flask import render_template
from pgeo.config.settings import settings
from pgeo.error.custom_exceptions import PGeoException
from pgeorest import app



@app.errorhandler(PGeoException)
def handle_invalid_usage(error):
    response = jsonify(error.to_dict())
    response.status_code = error.status_code
    return response


@app.errorhandler(404)
def page_not_found(e):
    return render_template('404.html'), 404


@app.route('/')
def root():
    return 'Welcome to p-geo!'

if __name__ == '__main__':
    app.run(host='localhost', port=settings['port'], debug=settings['debug'], threaded=True)


import json
from flask import Blueprint
from flask import Response
from flask import request
from flask.ext.cors import cross_origin
from pgeo.error.custom_exceptions import PGeoException
from pgeo.error.custom_exceptions import errors
from pgeo.config.settings import settings
from pgeo.metadata.metadata import merge_layer_metadata
from pgeo.metadata.db_metadata import DBMetadata


metadata = Blueprint('metadata', __name__)


@metadata.route('/')
@cross_origin(origins='*')
def index():
    return 'Welcome to the Metadata module!'

DBMetadata = DBMetadata(settings["db"]["metadata"])


@metadata.route('/create', methods=['POST'])
@metadata.route('/create/', methods=['POST'])
@cross_origin(origins='*', headers=['Content-Type'])
def create():
    """
    Store a metadata in the MongoDB
    @return: Acknowledge in JSON format: status_code, status_message, mongo_id
    """
    try:
        user_json = request.get_json()
        merged = merge_layer_metadata('modis', user_json)
        mongo_id = str(DBMetadata.insert_metadata(merged))
        response = {'status_code': 200, 'status_message': 'OK', 'mongo_id': mongo_id}
        return Response(json.dumps(response), content_type='application/json; charset=utf-8')
    except:
        raise PGeoException(errors[513], status_code=513)


@metadata.route('/delete/<id>', methods=['DELETE'])
@metadata.route('/delete/<id>/', methods=['DELETE'])
@cross_origin(origins='*', headers=['Content-Type'])
def delete(id):
    """
    REST service to delete a metadata from the DB.
    @param id: ID of the resource to be deleted.
    @return: MongoDB message
    """
    try:
        out = DBMetadata.remove_metadata_by_id(id)
        return Response(json.dumps(out), content_type='application/json; charset=utf-8')
    except:
        raise PGeoException(errors[513], status_code=513)


from flask import Flask
from flask.ext.cors import CORS

from pgeorest.browse_modis import browse_modis
from pgeorest.download import download
# from pgeorest.browse_trmm1 import browse_trmm1
from pgeorest.browse_trmm2 import browse_trmm2
from pgeorest.schema import schema
from pgeorest.filesystem import filesystem
from pgeorest.metadata import metadata
from pgeorest.search import search
from pgeorest import stats
from pgeorest import spatialquery
from pgeorest import distribution
import logging


app = Flask(__name__)
cors = CORS(app, resources={r'/*': {'origins': '*'}})

app.register_blueprint(browse_modis, url_prefix='/browse/modis')
# app.register_blueprint(browse_trmm1, url_prefix='/browse/trmm1')
app.register_blueprint(browse_trmm2, url_prefix='/browse/trmm2')

app.register_blueprint(download, url_prefix='/download')
app.register_blueprint(schema, url_prefix='/schema')
app.register_blueprint(filesystem, url_prefix='/filesystem')
app.register_blueprint(metadata, url_prefix='/metadata')
app.register_blueprint(search, url_prefix='/search')
app.register_blueprint(stats.app, url_prefix='/stats')
app.register_blueprint(spatialquery.app, url_prefix='/spatialquery')
app.register_blueprint(distribution.app, url_prefix='/distribution')

log = logging.getLogger('werkzeug')
log.setLevel(logging.ERROR)



import json
from flask import Blueprint, Response
from flask.ext.cors import cross_origin
import copy
from pgeo.error.custom_exceptions import PGeoException, errors
from pgeo.utils import log
from pgeo.config.settings import settings
from pgeo.stats.raster import Stats
from flask import request


app = Blueprint(__name__, __name__)
log = log.logger(__name__)

# Module to process statistics
stats = Stats(settings)

# default json_statistics

raster_statistics = {
    "raster": {
        "uid": None
    },
    "stats": {
        "force": True
    }
}


raster_histogram = {
    "raster": {
        "uid": None
    },
    "stats": {
        "force": True,
        "buckets": 256
    }
}

@app.route('/')
def index():
    """
        Welcome message
        @return: welcome message
    """
    return 'Welcome to the stats module!'


# @app.route('/raster/<layer>', methods=['GET'], headers=['Content-Type'])
# @app.route('/raster/<layer>/',  methods=['GET'], headers=['Content-Type'])
# @cross_origin(origins='*', headers=['Content-Type'])
@app.route('/raster/<layer>/',  methods=['GET'])
@app.route('/raster/<layer>', methods=['GET'])
def get_stats(layer):
    """
    Extracts all the statistics of a layer
    @param layer: workspace:layername
    @return: json with the raster statistics
    """
    try:
        if ":" not in layer:
            return PGeoException("Please Specify a workspace for " + str(layer), status_code=500)

        json_stats = raster_statistics
        json_stats["raster"]["uid"] = layer
        return Response(json.dumps(stats.get_stats(json_stats)), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())

@app.route('/raster/<layer>/hist/', methods=['GET'])
@app.route('/raster/<layer>/hist', methods=['GET'])
@cross_origin()
def get_histogram(layer):
    """
    Extracts histogram from a layer
    @param layer: workspace:layername
    @return: json with the raster statistics
    """
    try:
        if ":" not in layer:
            return PGeoException("Please Specify a workspace for " + str(layer), status_code=500)

        json_stats = raster_histogram
        json_stats["raster"]["uid"] = layer
        return Response(json.dumps(stats.get_histogram(json_stats)), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())

@app.route('/raster/<layer>/hist/<buckets>/', methods=['GET'])
@app.route('/raster/<layer>/hist/<buckets>', methods=['GET'])
@cross_origin(origins='*')
def get_histogram_buckets(layer, buckets):
    """
    Extracts histogram from a layer
    TODO: add a boolean and buckets
    default: boolean = True, buckets = 256
    @param layer: workspace:layername
    @param buckets: number of buckets i.e. 256
    @return: json with the raster statistics
    """
    try:
        if ":" not in layer:
            return PGeoException("Please Specify a workspace for " + str(layer), status_code=500)

        json_stats = raster_histogram
        json_stats["raster"]["uid"] = layer
        json_stats["stats"]["buckets"] = int(buckets)
        return Response(json.dumps(stats.get_histogram(json_stats)), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())

@app.route('/raster/<layer>/lat/<lat>/lon/<lon>/', methods=['GET'])
@app.route('/raster/<layer>/lat/<lat>/lon/<lon>', methods=['GET'])
@cross_origin(origins='*')
def get_lat_lon(layer, lat, lon):
    """
    Get the value of the layer at lat/lon position
    @param layer: workspace:layername
    @param lat: latitude
    @param lon: longitude
    @return: json with the raster statistics
    """
    try:
        if ":" not in layer:
            return PGeoException("Please Specify a workspace for " + str(layer), status_code=500)
        return Response({ "TODO" : "TODO"}, content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())


@app.route('/raster/spatial_query/', methods=['POST'])
@app.route('/raster/spatial_query', methods=['POST'])
@cross_origin(origins='*', headers=['Content-Type'])
def get_stats_by_layer():
    try:
        user_json = request.get_json()
        s = stats.zonal_stats(user_json)
        return Response(json.dumps(s), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())


@app.route('/rasters/spatial_query/', methods=['POST'])
@app.route('/rasters/spatial_query', methods=['POST'])
@cross_origin(origins='*', headers=['Content-Type'])
def get_stats_by_layers():
    try:
        user_json = request.get_json()
        response = []
        for uid in user_json["raster"]["uids"]:
            json_stat = copy.deepcopy(user_json)
            json_stat["raster"]["uid"] = uid
            s = {}
            s[uid] = stats.zonal_stats(json_stat)
            response.append(s)
        return Response(json.dumps(response), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())



from flask import Blueprint
from flask import Response
from flask.ext.cors import cross_origin
from pgeo.metadata.search import MongoSearch
from bson import json_util
from pgeo.config.settings import settings


search = Blueprint('search', __name__)
connection = settings['db']['metadata']['connection']
db = settings['db']['metadata']['database']
doc = settings['db']['metadata']['document']['layer']
mongo_search = MongoSearch(connection, db, doc)


@search.route('/')
@cross_origin(origins='*')
def index():
    return 'Welcome to the Schema module!'


@search.route('/layer/id/<id>', methods=['GET'])
@search.route('/layer/id/<id>/', methods=['GET'])
@cross_origin(origins='*')
def find_layer_by_id_service(id):
    out = json_util.dumps(mongo_search.find_layer_by_id(id))
    return Response(out, content_type='application/json; charset=utf-8')


@search.route('/layer/dekad/<dekad>', methods=['GET'])
@search.route('/layer/dekad/<dekad>/', methods=['GET'])
@cross_origin(origins='*')
def find_layer_by_dekad_service(dekad):
    out = json_util.dumps(mongo_search.find_layers_by_product(None, dekad, None))
    return Response(out, content_type='application/json; charset=utf-8')


@search.route('/layer/product/<product>', methods=['GET'])
@search.route('/layer/product/<product>/', methods=['GET'])
@cross_origin(origins='*')
def find_layer_by_product_service(product):
    out = json_util.dumps(mongo_search.find_layers_by_product(product, None, None))
    return Response(out, content_type='application/json; charset=utf-8')


@search.route('/layer/product/<product>/type/<aggregation_type>', methods=['GET'])
@search.route('/layer/product/<product>/type/<aggregation_type>/', methods=['GET'])
@cross_origin(origins='*')
def find_layer_by_product_and_type_service(product, aggregation_type):
    out = json_util.dumps(mongo_search.find_layers_by_product(product, None, aggregation_type))
    return Response(out, content_type='application/json; charset=utf-8')



@search.route('/layer/product/<product>/dekad/<dekad>', methods=['GET'])
@search.route('/layer/product/<product>/dekad/<dekad>/', methods=['GET'])
@cross_origin(origins='*')
def find_layer_by_product_and_dekad_service(product, dekad):
    out = json_util.dumps(mongo_search.find_layers_by_product(product, dekad, None))
    return Response(out, content_type='application/json; charset=utf-8')


@search.route('/layer/product/<product>/dekad/<dekad>/type/<aggregation_type>', methods=['GET'])
@search.route('/layer/product/<product>/dekad/<dekad>/type/<aggregation_type>/', methods=['GET'])
@cross_origin(origins='*')
def find_layer_by_product_and_dekad_and_type_service(product, dekad, aggregation_type):
    out = json_util.dumps(mongo_search.find_layers_by_product(product, dekad, aggregation_type))
    return Response(out, content_type='application/json; charset=utf-8')


@search.route('/layer/from/<dekad_from>/to/<dekad_to>/product/<product>', methods=['GET'])
@search.route('/layer/from/<dekad_from>/to/<dekad_to>/product/<product>/', methods=['GET'])
@cross_origin(origins='*')
def find_layer_by_dekad_range(dekad_from, dekad_to, product):
    out = json_util.dumps(mongo_search.find_layers_by_dekad_range(dekad_from, dekad_to, product))
    return Response(out, content_type='application/json; charset=utf-8')


@search.route('/layer/from/<dekad_from>/to/<dekad_to>', methods=['GET'])
@search.route('/layer/from/<dekad_from>/to/<dekad_to>/', methods=['GET'])
@cross_origin(origins='*')
def find_layer_by_dekad_range_and_product(dekad_from, dekad_to):
    out = json_util.dumps(mongo_search.find_layers_by_dekad_range(dekad_from, dekad_to, None))
    return Response(out, content_type='application/json; charset=utf-8')


@search.route('/layer/distinct/<field>', methods=['GET'])
@search.route('/layer/distinct/<field>/', methods=['GET'])
@cross_origin(origins='*')
def find_distinct(field):
    out = json_util.dumps(mongo_search.find_all(field))
    return Response(out, content_type='application/json; charset=utf-8')


import json
from flask import Blueprint
from flask import jsonify
from flask.ext.cors import cross_origin
from flask import request
from flask import Response
from pgeo.error.custom_exceptions import PGeoException
from pgeo.thread.download_threads_manager import Manager
from pgeo.thread.bulk_download_threads_manager import BulkDownloadManager
from pgeo.thread.bulk_download_threads_manager import progress_map as bulk_progress_map
from pgeo.thread.download_threads_manager import multi_progress_map
from pgeo.thread.download_threads_manager import out_template
from pgeo.gis.raster import process_hdfs
from pgeo.config.settings import read_config_file_json


download = Blueprint('download', __name__)
managers = {}


@download.route('/')
def index():
    return 'Welcome to the Download module!'


@download.route('/<source_name>', methods=['POST'])
@download.route('/<source_name>/', methods=['POST'])
@cross_origin(origins='*', headers=['Content-Type'])
def manager_start(source_name):
    try:
        payload = request.get_json()
        file_paths_and_sizes = payload['file_paths_and_sizes']
        filesystem_structure = payload['filesystem_structure']
        tab_id = payload['tab_id']
        if tab_id not in managers:
            managers[tab_id] = {}
        mgr = Manager(source_name, file_paths_and_sizes, filesystem_structure, tab_id)
        target_dir = mgr.run()
        out = {'source_path': target_dir}
        return Response(json.dumps(out), content_type='application/json; charset=utf-8')
    except Exception, e:
        print e
        raise PGeoException(e.message, 500)


@download.route('/progress/<tab_index>/<layer_name>')
@download.route('/progress/<tab_index>/<layer_name>/')
@cross_origin(origins='*')
def multiple_progress(layer_name, tab_index):
    if tab_index not in multi_progress_map:
        return jsonify(progress=out_template)
    if layer_name not in multi_progress_map[tab_index]:
        return jsonify(progress=out_template)
    return jsonify(multi_progress_map[tab_index][layer_name])


@download.route('/process/<source_name>', methods=['POST'])
@download.route('/process/<source_name>/', methods=['POST'])
@cross_origin(origins='*', headers=['Content-Type'])
def process_rasters_service(source_name):
    try:
        payload = request.get_json()
        conf = read_config_file_json(source_name, 'data_providers')
        obj = conf['processing']
        obj['source_path'] = payload['source_path']
        obj['output_path'] = payload['source_path'] + '/OUTPUT'
        obj['gdalwarp']['-tr'] = str(payload['pixel_size']) + ', -' + str(payload['pixel_size'])
        try:
            tiff = process_hdfs(obj)
            return Response(json.dumps('{"TIFF":"' + tiff + '"}'), content_type='application/json; charset=utf-8')
        except Exception, e:
            return Response(json.dumps('{"Message":"' + e.message + '"}'), content_type='application/json; charset=utf-8')
    except Exception, e:
        return Response(json.dumps('{"Message":"' + e.message + '"}'), content_type='application/json; charset=utf-8')


@download.route('/bulk/<source_name>', methods=['POST'])
@download.route('/bulk/<source_name>/', methods=['POST'])
@cross_origin(origins='*', headers=['Content-Type'])
def bulk_manager_start(source_name):
    try:
        payload = request.get_json()
        filesystem_structure = payload['filesystem_structure']
        bulk_download_objects = payload['bulk_download_objects']
        tab_id = payload['tab_id']
        mgr = BulkDownloadManager(source_name, filesystem_structure, bulk_download_objects, tab_id)
        target_dir = mgr.run()
        out = {'source_path': target_dir}
        return Response(json.dumps(out), content_type='application/json; charset=utf-8')
    except Exception, e:
        raise PGeoException(e.message, 500)


@download.route('/bulk/progress/<tab_index>')
@download.route('/bulk/progress/<tab_index>/')
@cross_origin(origins='*')
def bulk_progress(tab_index):
    if tab_index not in bulk_progress_map:
        return jsonify(progress=out_template)
    status = bulk_progress_map[tab_index]['status']
    print bulk_progress_map[tab_index]
    if 'ERROR' in status:
        raise PGeoException(status, 500)
    if 'COMPLETE' in status:
        raise PGeoException(status, 500)
    return jsonify(bulk_progress_map[tab_index])


import json
from flask import Blueprint, Response
from flask.ext.cors import cross_origin
from pgeo.error.custom_exceptions import PGeoException, errors
from pgeo.utils import log
from pgeo.config.settings import settings
from pgeo.db.postgresql.common import DBConnection
from flask import request

app = Blueprint(__name__, __name__)
log = log.logger(__name__)
spatial_db = DBConnection(settings["db"]["spatial"])

@app.route('/')
def index():
    return 'Welcome to the Spatial Query module!'


@app.route('/db/<datasource>/<query>/', methods=['GET'])
@app.route('/db/<datasource>/<query>', methods=['GET'])
@cross_origin(origins='*', headers=['Content-Type'])
def query_db(datasource, query):
    try:

        spatial_db = DBConnection(settings["db"][datasource])
        result = spatial_db.query(query)
        return Response(json.dumps(result), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())




import json
from flask import Blueprint, Response
from flask.ext.cors import cross_origin
import copy
from pgeo.error.custom_exceptions import PGeoException, errors
from pgeo.utils import log
from pgeo.config.settings import settings
from flask import request, send_from_directory
from shutil import move
import os
import uuid
from pgeo.gis.raster import crop_by_vector_database, get_authority
from pgeo.stats.raster import Stats
from pgeo.utils.filesystem import create_folder_in_tmp, get_filename, zip_files
from pgeo.utils import email_utils

app = Blueprint(__name__, __name__)
log = log.logger(__name__)


stats = Stats(settings)
db_spatial = stats.db_spatial
distribution_folder = settings["folders"]["distribution"]
zip_filename = "layers.zip"

email_user = settings["email"]["user"]
email_password = settings["email"]["password"]

email_header = "Raster layers"
email_body = "<html><head></head>" \
             "<body>" \
             "<div><b>PGeo - Distribution Service</b></div>" \
             "<div style='padding-top:10px;'>The layers you asked to download are available at the following link:</div>" \
             "<div style='padding-top:10px;'><a href='{{LINK}}'>Download Zip File</a></div>" \
             "<div style='padding-top:10px;'><b>Please note that the link will work for the next 24h hours</b></div>" \
             "</body>" \
             "</html>"

@app.route('/')
def index():
    """
        Welcome message
        @return: welcome message
    """
    return 'Welcome to the distribution module!'


@app.route('/raster/spatial_query', methods=['POST'])
@app.route('/raster/spatial_query', methods=['POST'])
@cross_origin(origins='*', headers=['Content-Type'])
def get_layers_post():
    try:
        # TODO: it should be a Thread

        user_json = request.get_json()
        uids = user_json["raster"]["uids"]
        json_filter = json.loads(user_json["vector"])
        email_address = None if "email_address" not in user_json else user_json["email_address"]

        log.info(uids)
        log.info(json_filter)
        log.info(email_address)

        # create a random tmp folder
        zip_folder_id = str(uuid.uuid4()).encode("utf-8")
        zip_folder = os.path.join(distribution_folder, zip_folder_id)
        os.mkdir(zip_folder)

        # create a valid folder name to zip it
        output_folder = os.path.join(zip_folder, "layers")
        os.mkdir(output_folder)

        output_files = []
        for uid in uids:
            log.info(uid)
            raster_path = stats.get_raster_path(uid)

            authority_name, authority_code  = get_authority(raster_path)
            log.info(db_spatial.schema)
            log.info(authority_name)
            log.info(authority_code)


            query_extent = json_filter["query_extent"]
            query_layer = json_filter["query_layer"]

            query_extent = query_extent.replace("{{SCHEMA}}", db_spatial.schema)
            query_extent = query_extent.replace("{{SRID}}", authority_code)
            query_layer = query_layer.replace("{{SCHEMA}}", db_spatial.schema)

            # create the file on tm folder
            filepath = crop_by_vector_database(raster_path, db_spatial, query_extent, query_layer)

            # move file to distribution tmp folder
            path, filename, name = get_filename(filepath, True)
            dst_file = os.path.join(output_folder, filename)
            #dst_file = tmp_folder

            log.info(filepath)
            log.info(dst_file)
            move(filepath, dst_file)

            # rename file based on uid layer_name (i.e. fenix:trmm_08_2014 -> trmm_08_2014)
            output_filename = uid.split(":")[1] + ".geotiff"
            output_file = os.path.join(output_folder, output_filename)
            os.rename(dst_file, output_file)

            # saving the output file to zip
            output_files.append(output_file)

        # zip folder or files
        zip_files(zip_filename, output_files, zip_folder )

        # URL to the resource
        url = request.host_url +"distribution/download/" + zip_folder_id

        # send email if email address
        if email_address:
            log.info("sending email to: %s" % email_address)
            html = email_body.replace("{{LINK}}", url)
            email_utils.send_email(email_user, email_address, email_password, email_header, html)

        return Response(json.dumps('{ "url" : "' + url + '"}'), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())


#http://localhost:5005/distribution/raster/fenix:trmm_06_2014;fenix:trmm_07_2014;fenix:trmm_08_2014;fenix:rice_area1;fenix:apple_area1;fenix:banana_area1/spatial_query/{ "vector" : { "query_extent" : "SELECT ST_AsGeoJSON(ST_Extent(geom)) FROM {{SCHEMA}}.gaul0_3857_test WHERE adm0_name IN ('Spain', 'Italy', 'Germany','China')", "query_layer" : "SELECT * FROM {{SCHEMA}}.gaul0_3857_test WHERE adm0_name IN ('Spain', 'Italy', 'Germany','China')"}}
#http://localhost:5005/distribution/raster/fenix:MODIS_brazil_korea/spatial_query/%7B%20%22vector%22%20:%20%7B%20%22query_extent%22%20:%20%22SELECT%20ST_AsGeoJSON%28ST_Transform%28ST_SetSRID%28ST_Extent%28geom%29,%203857%29,%20%7B%7BSRID%7D%7D%29%29%20FROM%20%7B%7BSCHEMA%7D%7D.gaul0_3857_test%20WHERE%20adm0_name%20IN%20%28%27Brazil%27%29%22,%20%22query_layer%22%20:%20%22SELECT%20*%20FROM%20%7B%7BSCHEMA%7D%7D.gaul0_3857_test%20WHERE%20adm0_name%20IN%20%28%27Brazil%27%29%22%7D%7D
@app.route('/raster/<uids>/spatial_query/<spatial_query>/', methods=['GET'])
@app.route('/raster/<uids>/spatial_query/<spatial_query>', methods=['GET'])
@cross_origin(origins='*', headers=['Content-Type'])
def get_layers(uids, spatial_query):
    try:
        log.info(uids)
        log.info(spatial_query)
        uids = uids.split(";")
        log.info(uids)
        log.info(spatial_query)
        json_filter = json.loads(spatial_query)

        # create a random tmp folder
        zip_folder_id = str(uuid.uuid4()).encode("utf-8")
        zip_folder = os.path.join(distribution_folder, zip_folder_id)
        os.mkdir(zip_folder)

        # create a valid folder name to zip it
        output_folder = os.path.join(zip_folder, "layers")
        os.mkdir(output_folder)

        output_files = []
        for uid in uids:
            log.info(uid)
            raster_path = stats.get_raster_path(uid)

            authority_name, authority_code  = get_authority(raster_path)
            log.info(db_spatial.schema)
            log.info(authority_name)
            log.info(authority_code)


            query_extent = json_filter["vector"]["query_extent"]
            query_layer = json_filter["vector"]["query_layer"]

            query_extent = query_extent.replace("{{SCHEMA}}", db_spatial.schema)
            query_extent = query_extent.replace("{{SRID}}", authority_code)
            query_layer = query_layer.replace("{{SCHEMA}}", db_spatial.schema)

            # create the file on tm folder
            filepath = crop_by_vector_database(raster_path, db_spatial, query_extent, query_layer)

            # move file to distribution tmp folder
            path, filename, name = get_filename(filepath, True)
            dst_file = os.path.join(output_folder, filename)
            #dst_file = tmp_folder

            log.info(filepath)
            log.info(dst_file)
            move(filepath, dst_file)

            # rename file based on uid layer_name (i.e. fenix:trmm_08_2014 -> fenix_trmm_08_2014)
            output_filename = uid.replace(":", "_") + ".geotiff"
            output_file = os.path.join(output_folder, output_filename)
            os.rename(dst_file, output_file)

            # saving the output file to zip
            output_files.append(output_file)

        # zip folder or files
        zip_files(zip_filename, output_files, zip_folder )

        # send email
        # if email_address:
        #     log.info("sending email to: %s" % email_address)
        #     html = email_body.replace("{{LINK}}", url)
        #     email_utils.send_email(email_user, email_address, email_password, email_header, html)

        url = request.host_url +"distribution/download/" + zip_folder_id
        return Response(json.dumps('{ "url" : "'+ url + '"}'), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())



@app.route('/download/<id>', methods=['GET'])
@app.route('/download/<id>/', methods=['GET'])
@cross_origin(origins='*', headers=['Content-Type'])
def get_zip_file(id):
    try:
        log.info(request.base_url)
        log.info(request.path)
        # log.info(distribution_folder + str(id) +"/" + zip_filename)
        return send_from_directory(directory=distribution_folder + str(id), filename=zip_filename,  as_attachment=True, attachment_filename=zip_filename)
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())



import json
from flask import Blueprint
from flask import Response
from flask.ext.cors import cross_origin
from pgeo.error.custom_exceptions import PGeoException
from pgeo.error.custom_exceptions import errors
from pgeo.config.settings import read_config_file_json
from pgeo.utils.filesystem import list_sources

schema = Blueprint('schema', __name__)


@schema.route('/')
@cross_origin(origins='*')
def index():
    return 'Welcome to the Schema module!'


@schema.route('/sources', methods=['GET'])
@schema.route('/sources/', methods=['GET'])
@cross_origin(origins='*')
def list_sources_service():
    try:
        out = list_sources()
        return Response(json.dumps(out), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())


@schema.route('/sources/<source_name>', methods=['GET'])
@schema.route('/sources/<source_name>/', methods=['GET'])
@cross_origin(origins='*')
def list_services(source_name):
    try:
        config = read_config_file_json(source_name, 'data_providers')
        out = {
            'base_url': config['services_base_url'],
            'services': config['services'],
            'ftp': config['source']['ftp']
        }
        return Response(json.dumps(out), content_type='application/json; charset=utf-8')
    except Exception, err:
        raise PGeoException(errors[511], status_code=511)


import json
from flask import Blueprint
from flask import Response
from flask.ext.cors import cross_origin
from pgeo.error.custom_exceptions import PGeoException
from pgeo.utils.filesystem import create_filesystem


filesystem = Blueprint('filesystem', __name__)


@filesystem.route('/')
@cross_origin(origins='*')
def index():
    """
    Welcome message
    @return: welcome message
    """
    return 'Welcome to the Filesystem module!'


@filesystem.route('/<source>')
@filesystem.route('/<source>/')
@cross_origin(origins='*')
def create_filesystem_service(source):
    """
    This service create the filesystem structure as specified in the configuration file.
    @param source: e.g. 'modis'
    @return: Result of the operation
    """
    try:
        create_filesystem(source, {'product': 'Simone', 'year': '2014', 'day': '1'})
        response = {'status_code': 200, 'status_message': 'OK'}
        return Response(json.dumps(response), content_type='application/json; charset=utf-8')
    except:
        raise PGeoException('Error', status_code=500)


import json
from flask import Blueprint
from flask import Response
from flask.ext.cors import cross_origin
from pgeo.config.settings import read_config_file_json
from pgeo.error.custom_exceptions import PGeoException
from pgeo.dataproviders import trmm2 as t


browse_trmm2 = Blueprint('browse_trmm2', __name__)
conf = read_config_file_json('trmm2', 'data_providers')


@browse_trmm2.route('/')
@cross_origin(origins='*')
def list_years_service():
    try:
        out = t.list_years()
        return Response(json.dumps(out), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())


@browse_trmm2.route('/<year>')
@browse_trmm2.route('/<year>/')
@cross_origin(origins='*')
def list_months_service(year):
    try:
        out = t.list_months(year)
        return Response(json.dumps(out), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())


@browse_trmm2.route('/<year>/<month>')
@browse_trmm2.route('/<year>/<month>/')
@cross_origin(origins='*')
def list_days_service(year, month):
    try:
        out = t.list_days(year, month)
        return Response(json.dumps(out), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())


@browse_trmm2.route('/<year>/<month>/<day>')
@browse_trmm2.route('/<year>/<month>/<day>/')
@cross_origin(origins='*')
def list_layers_service(year, month, day):
    try:
        out = t.list_layers(year, month, day)
        return Response(json.dumps(out), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())


@browse_trmm2.route('/<year>/<month>/<from_day>/<to_day>')
@browse_trmm2.route('/<year>/<month>/<from_day>/<to_day>/')
@cross_origin(origins='*')
def list_layers_subset_service(year, month, from_day, to_day):
    try:
        out = t.list_layers_subset(year, month, from_day, to_day)
        return Response(json.dumps(out), content_type='application/json; charset=utf-8')
    except PGeoException, e:
        raise PGeoException(e.get_message(), e.get_status_code())


from setuptools import setup
from setuptools import find_packages

setup(
    name='PGeoREST',
    version='0.1.11',
    author='Simone Murzilli; Guido Barbaglia',
    author_email='geobrickspy@gmail.com',
    packages=find_packages(),
    url='http://pypi.python.org/pypi/PGeoREST/',
    license='LICENSE.txt',
    description='PGeoREST module.',
    long_description=open('README.txt').read(),
    install_requires=[
        'flask',
        'flask-cors',
        'pgeo'
    ]
)
